use serde::{Deserialize, Serialize};

use super::trust_dns_types;


#[derive(Deserialize, Serialize, Clone)]
pub enum DNSClass {
    IN,
    CH,
    HS,
    NONE,
    ANY,
    OPT(u16),
}

impl From<trust_dns_types::DNSClass> for DNSClass {
    fn from(dns_class: trust_dns_types::DNSClass) -> DNSClass {
        match dns_class {
            trust_dns_types::DNSClass::IN => DNSClass::IN,
            trust_dns_types::DNSClass::CH => DNSClass::CH,
            trust_dns_types::DNSClass::HS => DNSClass::HS,
            trust_dns_types::DNSClass::NONE => DNSClass::NONE,
            trust_dns_types::DNSClass::ANY => DNSClass::ANY,
            trust_dns_types::DNSClass::OPT(v) => DNSClass::OPT(v),
        }
    }
}

impl From<DNSClass> for trust_dns_types::DNSClass {
    fn from(dns_class: DNSClass) -> trust_dns_types::DNSClass {
        match dns_class {
            DNSClass::IN => trust_dns_types::DNSClass::IN,
            DNSClass::CH => trust_dns_types::DNSClass::CH,
            DNSClass::HS => trust_dns_types::DNSClass::HS,
            DNSClass::NONE => trust_dns_types::DNSClass::NONE,
            DNSClass::ANY => trust_dns_types::DNSClass::ANY,
            DNSClass::OPT(v) => trust_dns_types::DNSClass::OPT(v),
        }
    }
}